@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::inverseModc(BigInt const &mod) const
+BigInt BigInt::inverseModc(BigInt const &mod) const
 {
     BigInt ret(*this);
     mod_inverse(&ret, mod);
