@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::rshiftc() const
+BigInt BigInt::rshiftc() const
 {
     BigInt ret(*this);
     ret.rshift();
