@@ -2,7 +2,7 @@
 
 DateTime &DateTime::operator+=(time_t seconds)
 {
-    d_time += seconds;
-    utcSec2timeStruct(&d_tm, d_time);
+    d_utcSec += seconds;
+    utcSec2timeStruct(&d_tm, d_utcSec);
     return *this;
 }
