@@ -2,19 +2,20 @@
                               server.cc
 */
 
+#include <unistd.h>
+
 #include <iostream>
+#include <exception>
 
 #include <bobcat/a2x>
 #include <bobcat/serversocket>
-#include <bobcat/errno>
 #include <bobcat/ifdstream>
 
 
 using namespace std;
 using namespace FBB;
 
-
-int main(int argc, char **argv, char **envp)
+int main(int argc, char **argv)
 try
 {
     if (argc == 1)
@@ -53,8 +54,8 @@ try
     }  
 
 }
-catch(Errno const &error)
+catch(exception const &error)
 {
-    cerr << error.why() << endl;
+    cerr << error.what() << endl;
     return 1;
 }
