@@ -3,6 +3,7 @@
 EncryptBufImp::EncryptBufImp(ostream &outStream, string const &ivv, 
                              size_t bufsize)
 :
+    ctx(EVP_CIPHER_CTX_new()),
     active(false),
     bufsize(bufsize),
     buffer(0),
@@ -16,12 +17,13 @@ EncryptBufImp::EncryptBufImp(ostream &outStream, string const &ivv,
 
         IRandStream irs(0, 255, time(0));
 
-        for_each(
-            iv.begin(), iv.end(), 
-            [&](char &ch)
-            {
-                setChar(ch, irs);
-            }
-        );
+        for (auto &ch: iv)
+            setChar(ch, irs);
     }
 }
+
+
+
+
+
+
