@@ -2,8 +2,10 @@
 
 int HMacBuf::overflow(int c)
 {
-    HMAC_Update(&d_pimpl->ctx, 
-                    reinterpret_cast<unsigned char *>(d_pimpl->buffer), d_pimpl->bufsize);
+    HMAC_Update(d_pimpl->ctx, 
+                reinterpret_cast<unsigned char *>(d_pimpl->buffer), 
+                d_pimpl->bufsize);
+
     setp(d_pimpl->buffer, d_pimpl->buffer + d_pimpl->bufsize);
 
     if (c != EOF)
