@@ -2,6 +2,6 @@
 
 void LogBuffer::settimestamp(TimeStamps timestamps, char const *delim)
 {
-    if ((d_insertTimestamp = (timestamps == TIMESTAMPS)))
+    if ( (d_timestamps = timestamps) != NOTIMESTAMPS)
         d_delim = !delim ? "" : delim;
 }
