@@ -9,12 +9,12 @@
 #include <algorithm>
 #include <iterator>
 
-#include <bobcat/errno>
+#include <bobcat/exception>
 
 using namespace std;
 using namespace FBB;
 
-int main(int argc, char **argv, char **envp)
+int main(int argc, char **argv)
 {
     MailHeaders mh(cin, MailHeaders::DONT_READ);
 
@@ -22,9 +22,9 @@ int main(int argc, char **argv, char **envp)
     {
         mh.read();
     }
-    catch (Errno &err)
+    catch (exception &err)
     {
-        cout << err.why() << endl;
+        cout << err.what() << endl;
     }
 
     mh.setHeaderIterator("Received");  
@@ -51,11 +51,4 @@ int main(int argc, char **argv, char **envp)
     mh.setHeaderIterator("From", MailHeaders::PARTIAL);  
 
     copy(mh.beginh(), mh.endh(),  ostream_iterator<string>(cout, "\n"));
-
-    return 0;
 }
-
-
-
-
-
