@@ -2,8 +2,7 @@
 
 string  Pattern::operator[](size_t index) const
 {
-    regoff_t
-        begin;
+    regoff_t begin;
 
     return
         (
