@@ -7,4 +7,7 @@ SharedStreambuf::SharedStreambuf(
     d_openMode(openMode),
     d_currentMode(openMode & (ios::in | ios::out)),
     d_memory(maxSize, sizeUnit, access)
-{}
+{
+    setg(0, 0, 0);
+    setp(0, 0);
+}
