@@ -3,15 +3,15 @@
 string String::escape(string const &str, char const *series)
 {
     string ret;
-    size_type left = 0;
+    string::size_type left = 0;
 
     while (true)
     {
-        size_type right = str.find_first_of(series, left);
+        string::size_type right = str.find_first_of(series, left);
 
         ret += str.substr(left, right - left);  // append until separator
 
-        if (right == npos)                  // done when all copied
+        if (right == string::npos)                  // done when all copied
             return ret;
 
         ret += "\\";                        // append backslash
