@@ -24,7 +24,7 @@ User::User()
         }
     }
 
-    throw Exception(1) << 
+    throw Exception{1} << 
         "Unable to determine actual user information from `/etc/passwd'";
 }
 
